@@ -483,18 +483,6 @@ while (time < $s) {
     $F->blit_write($image);
 }
 
-print_it($F,'Testing Resized Image Blitting');
-$s = time + $factor;
-while (time < $s) {
-    my $new = $image;
-    $new->{'newwidth'} = int(rand($XX));
-    $new->{'newheight'} = int(rand($YY));
-    $new = $F->resize_image($new);
-    $new->{'x'} = abs(rand($XX - $new->{'width'}));
-    $new->{'y'} = abs(rand($YY - $new->{'height'}));
-    $F->blit_write($new);
-}
-
 $F->cls('ON');
 
 exit(0);
