@@ -9,11 +9,11 @@ use strict;
 
 use Graphics::Framebuffer;
 
-my $mali = 0;
-$mali = 1 if ($ARGV[1] =~ /mali/i);
-
-my ($c, $p);
-my $f = Graphics::Framebuffer->new('MALI' => $mali, 'SPLASH' => 0, 'SHOW_ERRORS' => 1);
+my $f = Graphics::Framebuffer->new(
+#    'FB_DEVICE'   => '/dev/fb1',
+    'SPLASH'      => 0,
+    'SHOW_ERRORS' => 1
+);
 
 system('clear');
 $f->cls();
